@@ -10,8 +10,6 @@
 
  /***************************************************************/
 
-#if HAVE_DYN_COMPILE
-
 /* turn a running frame into its Psyco equivalent, a PsycoObject.
    Return Py_None if the frame cannot be turned into a PsycoObject.
    Never sets an exception. */
@@ -26,11 +24,7 @@ PSY_INLINE PyObject* PsycoObject_FromFrame(PyFrameObject* f, int recursion)
 	PyObject* merge_points;
 
 	if (f->f_stacktop == NULL) {
-          /*#if version >= 2.2.2*/
 		/* cannot patch a frame other than the top (running) one */
-          /*#else*/
-		/* feature requires Python version 2.2.2 or later */
-          /*#endif*/
 		goto fail;
 	}
         module = f->f_globals == f->f_locals;
@@ -348,8 +342,12 @@ bool PsycoCode_Run(PyObject* codebuf, PyFrameObject* f, bool entering)
 		   last instruction of any code object is a RETURN_VALUE. */
 		PyObject** p;
 		int new_i = PyString_GET_SIZE(co->co_code) - 1;
-		psyco_assert(PyString_AS_STRING(co->co_code)[new_i]
-                             == RETURN_VALUE);
+		/* Python 2.5: the bytecode doesn't always end with a
+		   RETURN_VALUE, but surely there must be one *somewhere* */
+		while (PyString_AS_STRING(co->co_code)[new_i] != RETURN_VALUE){
+			--new_i;
+			psyco_assert(new_i >= 0);
+		}
 #if PY_VERSION_HEX >= 0x02030000   /* 2.3 */
 		/* dubious compatibility hack for Python 2.3, in which f_lasti
 		   no longer always refer to the instruction that will be
@@ -374,8 +372,6 @@ bool PsycoCode_Run(PyObject* codebuf, PyFrameObject* f, bool entering)
 	}
 }
 
-#endif /* HAVE_DYN_COMPILE */
-
 
  /***************************************************************/
 
@@ -428,11 +424,11 @@ void PyFrameRuntime_dealloc(PyFrameRuntime* self)
 	/* nothing */
 }
 
-PSY_INLINE PyFrameObject* psyco_build_pyframe(PyObject* co, PyObject* globals)
+PSY_INLINE PyFrameObject* psyco_build_pyframe(PyObject* co, PyObject* globals,
+					      PyThreadState* tstate)
 {
 	PyFrameObject* back;
 	PyFrameObject* result;
-	PyThreadState* tstate = PyThreadState_GET();
 	
 	/* frame objects are not created in stack order
 	   with Psyco, so it's probably better not to
@@ -461,7 +457,7 @@ PyFrameObject* psyco_emulate_frame(PyObject* o)
 		PyObject* globals = PyTuple_GetItem(o, 1);
 		extra_assert(co != NULL);
 		extra_assert(globals != NULL);
-		return psyco_build_pyframe(co, globals);
+		return psyco_build_pyframe(co, globals, PyThreadState_GET());
 	}
 }
 
@@ -490,7 +486,8 @@ static PyObject* pvisitframes(PyObject*(*callback)(PyObject*,void*),
 	PyFrameRuntime* fstart;
 	PyObject* tdict = psyco_thread_dict();
 	PyFrameObject* f = PyThreadState_Get()->frame;
-	
+
+	RECLIMIT_SAFE_ENTER();
 	while (f != NULL) {
 		/* is this Python frame the starting point of a chained
 		   list of Psyco frames ? */
@@ -562,7 +559,7 @@ static PyObject* pvisitframes(PyObject*(*callback)(PyObject*,void*),
 				PyMem_FREE(p);
 			}
 			if (result != NULL)
-				return result;
+				break;
 
 			/* there is still the real Python frame
 			   which is shadowed by a Psyco frame, i.e. a
@@ -582,10 +579,11 @@ static PyObject* pvisitframes(PyObject*(*callback)(PyObject*,void*),
 			result = callback((PyObject*) f, data);
 		}
 		if (result != NULL)
-			return result;
+			break;
 		f = f->f_back;
 	}
-	return NULL;
+        RECLIMIT_SAFE_LEAVE();
+	return result;
 }
 
 
@@ -676,9 +674,8 @@ PyObject* psyco_get_globals(void)
 	return result;
 }
 
-#if HAVE_PYTHON_SUPPORT
 static PyFrameObject* cached_frame = NULL;
-static PyObject* visit_first_frame(PyObject* o, void* ignored)
+static PyObject* visit_first_frame(PyObject* o, void* ts)
 {
 	if (PyFrame_Check(o)) {
 		/* a real Python frame: don't return a new reference */
@@ -694,18 +691,22 @@ static PyObject* visit_first_frame(PyObject* o, void* ignored)
 		PyFrameObject* newf;
 		PyObject* co = PyTuple_GetItem(o, 0);
 		PyObject* globals = PyTuple_GetItem(o, 1);
+		PyThreadState* tstate = (PyThreadState*) ts;
 		extra_assert(co != NULL);
 		extra_assert(globals != NULL);
 		while (cached_frame != NULL) {
 			f = cached_frame;
 			if ((PyObject*) f->f_code == co
-			    && f->f_globals == globals)
-				return (PyObject*) f;  /* reuse it */
+			    && f->f_globals == globals) {
+				/* reuse the cached frame */
+				f->f_tstate = tstate;
+				return (PyObject*) f;
+			}
 			cached_frame = NULL;
 			Py_DECREF(f);  /* might set cached_frame again
 					  XXX could this loop never end? */
 		}
-		newf = psyco_build_pyframe(co, globals);
+		newf = psyco_build_pyframe(co, globals, tstate);
 		while (cached_frame != NULL) {
 			/* worst-case safe...  this is unlikely */
 			f = cached_frame;
@@ -718,9 +719,8 @@ static PyObject* visit_first_frame(PyObject* o, void* ignored)
 }
 static PyFrameObject* psyco_threadstate_getframe(PyThreadState* self)
 {
-	return (PyFrameObject*) pvisitframes(visit_first_frame, NULL);
+	return (PyFrameObject*) pvisitframes(visit_first_frame, (void*)self);
 }
-#endif
 
 
  /***************************************************************/
@@ -728,11 +728,9 @@ static PyFrameObject* psyco_threadstate_getframe(PyThreadState* self)
 INITIALIZATIONFN
 void psyco_frames_init(void)
 {
-#if HAVE_PYTHON_SUPPORT
 	_PyThreadState_GetFrame =
 #  if PYTHON_API_VERSION < 1012
 		(unaryfunc)
 #  endif
 		psyco_threadstate_getframe;
-#endif
 }
